﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
//네임스페이스
using Hippo;
using Hippo.WindowsForm4;

namespace WindowsForm_hippo
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        /// <summary>
        /// 폼로드
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void Form1_Load(object sender, EventArgs e)
        {
            foreach (ChartType chars in Enum.GetValues(typeof(ChartType)))
            {
                // 평가판에서 지원하지 않거나 일부 복잡한 데이터가 필요한 차트종류는 다른 샘플로 공유합니다.
                if (chars != ChartType.CandleStick && chars != ChartType.ImageBar 
                    && chars != ChartType.BoxPlot && chars != ChartType.Vector
                    && chars != ChartType.Gantt && chars != ChartType.Surface) 
                {
                    this.comboBox1.Items.Add(chars);
                }
            }

            Draw(ChartType.Line);
        }

        /// <summary>
        /// 새로고침
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void hHippoChart1_ChartSizeChanged(object sender, EventArgs e)
        {
            this.hHippoChart1.DrawChart();
        }

        /// <summary>
        /// 히포차트 그리기 (일반 차트)
        /// </summary>
        /// <param name="types"></param>
        private void Draw(ChartType types)
        {
            try
            {
                this.hHippoChart1.SeriesListDictionary.Clear();

                SeriesList sList = new SeriesList();
                sList.ChartType = types;

                Random r = new Random();
                for (int i = 0; i < 4; i++)
                {
                    Series sr = new Series();
                    sr.Line.LineWidth = 2;
                    sr.Points.Width = 5;
                    sr.Points.PointType = PointType.FillCircle;

                    for (int x = 0; x < 5; x++)
                    {
                        SeriesItem item = new SeriesItem();
                        item.Name = x.ToString();
                        item.YValue = r.Next(90);

                        sr.items.Add(item);
                    }
                    sList.SeriesCollection.Add(sr);
                }

                this.hHippoChart1.SeriesListDictionary.Add(sList);
                this.hHippoChart1.DrawChart();
            }
            catch 
            {
                MessageBox.Show("평가판에서는 일부 차트타입을 지원하지 않습니다.");
            }
        } 

        /// <summary>
        /// 차트 종류 변경
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void comboBox1_SelectedIndexChanged(object sender, EventArgs e)
        {
            this.Draw((ChartType)this.comboBox1.SelectedItem);
        }

        private void hHippoChart2_ChartSizeChanged(object sender, EventArgs e)
        {
            this.hHippoChart2.DrawChart();
        }

        private void hHippoChart3_ChartSizeChanged(object sender, EventArgs e)
        {
            this.hHippoChart3.DrawChart();
        }

        private void tabControl1_SelectedIndexChanged(object sender, EventArgs e)
        {
            if (this.tabControl1.SelectedIndex == 0)
            {
                // 일반 차트 
                this.Draw(ChartType.Column); 
            }
            else if (this.tabControl1.SelectedIndex == 1)
            {
                // 주식차트
                button1_Click(null, new EventArgs());
            }
            else if (this.tabControl1.SelectedIndex == 2)
            {
                // 간트차트
                DrawGanttChart();
            }
            else if (this.tabControl1.SelectedIndex == 3)
            {
                // 각종 이벤트 구현 
                DrawEventSample1(); 
            } 
            else if (this.tabControl1.SelectedIndex == 4)
            {
                // 각종 이벤트 구현 
                DrawEventSample2();
            }
            else if (this.tabControl1.SelectedIndex == 8)
            {
                // 계기판 차트
                DrawGaugeChart();
            }
        }

        // 주식차트에 사용된 변수들
        SeriesList sList;
        SeriesList sList2;
        int time = 0;

        /// <summary>
        /// 주식차트 그리기
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void button1_Click(object sender, EventArgs e)
        {
            this.hHippoChart2.SeriesListDictionary.Clear();

            HippoEngine en = new HippoEngine();
            en.DataType = DataSourceType.Excel;
            en.Query = "select * from [Sheet1$]";
            en.ConnectionString = @"Provider=Microsoft.ACE.OLEDB.12.0;Data Source='" + System.IO.Directory.GetCurrentDirectory() + "\\주식차트샘플2.xls';Extended Properties='Excel 12.0;HDR=YES'";

            sList = en.GetSeriesListOfStock(DataSourceType.Excel, "년/월", "시가", "종가", "저가", "고가");

            sList.ChartType = ChartType.CandleStick;

            sList.SeriesCollection[0].Name = "주가";

            //sList.GraphArea.Grid.Interval = 10;
            //sList.GraphArea.Grid.GridDirection = GridDirection.Vertical;

            //sList.AxisFactor.XAxis.LabelFormat.FormatFlags = StringFormatFlags.DirectionVertical;
            //sList.AxisFactor.XAxis.Interval = 10;

            sList.AxisFactor.YAxis.SetAxisStep(10000, 40000, 5000);


            double tempMaxHighval = double.MinValue;
            double tempMaxLowval = double.MaxValue;

            SeriesItem Highitem = new SeriesItem();
            SeriesItem Lowitem = new SeriesItem();

            foreach (SeriesItem item in sList.SeriesCollection[0].items)
            {
                if (item.HighValue > tempMaxHighval)
                {
                    tempMaxHighval = item.HighValue;
                    Highitem = item;
                }

                if (item.LowValue < tempMaxLowval)
                {
                    tempMaxLowval = item.LowValue;
                    Lowitem = item;
                }

                if (item.IsDojiType)
                {

                }
            }

            if (Highitem != null)
            {
                Highitem.Balloon = new Balloon();
                Highitem.Balloon.BalloonType = BalloonType.Rectangle;
                Highitem.Balloon.HeightType = HeightType.Bottom;
                Highitem.Balloon.BackColor = Color.White;
                Highitem.Balloon.Label.Text = "최고가 : " + Highitem.HighValue.ToString();
            }

            if (Lowitem != null)
            {
                Lowitem.Balloon = new Balloon();
                Lowitem.Balloon.BalloonType = BalloonType.Rectangle;
                Lowitem.Balloon.HeightType = HeightType.Bottom;
                Lowitem.Balloon.BackColor = Color.White;
                Lowitem.Balloon.Label.Text = "최저가 : " + Highitem.LowValue.ToString();
            }

            sList.AxisFactor.XAxis.UnitPixel = 22;

            sList.SeriesCollection[0].items[11].Balloon = new Balloon();
            sList.SeriesCollection[0].items[11].Balloon.BalloonType = BalloonType.Rectangle;
            sList.SeriesCollection[0].items[11].Balloon.BackColor = Color.White;
            sList.SeriesCollection[0].items[11].Balloon.HeightType = HeightType.Bottom;
            sList.SeriesCollection[0].items[11].Balloon.Label.Text = "\r\n ---주식 시세 정보---\r\n";
            sList.SeriesCollection[0].items[11].Balloon.Label.Text += "\r\n - 시가: " + sList.SeriesCollection[0].items[11].YStartValue.ToString("n0");
            sList.SeriesCollection[0].items[11].Balloon.Label.Text += "\r\n - 종가: " + sList.SeriesCollection[0].items[11].YValue.ToString("n0");
            sList.SeriesCollection[0].items[11].Balloon.Label.Text += "\r\n - 저가: " + sList.SeriesCollection[0].items[11].LowValue.ToString("n0");
            sList.SeriesCollection[0].items[11].Balloon.Label.Text += "\r\n - 고가: " + sList.SeriesCollection[0].items[11].HighValue.ToString("n0");
            sList.SeriesCollection[0].items[11].Balloon.Label.Text += "\r\n";



            this.hHippoChart2.LegendBox.Visible = false;
            this.hHippoChart2.SeriesListDictionary.Add(sList);
            this.hHippoChart2.DrawChart(); 
        }

        /// <summary>
        /// 주식차트 실시간 형태로 보기
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void button2_Click(object sender, EventArgs e)
        {
            this.hHippoChart2.SeriesListDictionary.Clear();
            this.timer1.Interval = 1000;

            sList2 = new SeriesList();
            sList2.ChartType = ChartType.CandleStick;
            sList2.SeriesCollection.Add(new Series());
            sList2.AxisFactor.XAxis.Interval = 2;

            // 실시간 셋 추가
            this.hHippoChart2.RealTimeList.Add(new Hippo.WindowsForm4.HippoRealTimeAttribute());

            this.hHippoChart2.SeriesListDictionary.Add(sList2);
            //this.hHippoChart1.DrawChart();

            this.timer1.Start();
        }

        /// <summary>
        /// 실시간 모양의 주식 차트
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void timer1_Tick(object sender, EventArgs e)
        {
            try
            {
                this.hHippoChart2.DrawRealTimeChart(sList.SeriesCollection[0].items[time], 10);

                time++;
            }
            catch
            {
                this.timer1.Stop();
            }
        }

        /// <summary>
        /// 간트차트 그리기
        /// </summary>
        private void DrawGanttChart()
        {
            this.hHippoChart3.SeriesListDictionary.Clear();

            Hippo.HippoEngine en = new HippoEngine();
            en.DataType = DataSourceType.Excel;
            en.ConnectionString = @"Provider=Microsoft.ACE.OLEDB.12.0;Data Source='"+ System.IO.Directory.GetCurrentDirectory() +"\\프로젝트간트차트샘플.xlsx';Extended Properties='Excel 12.0;HDR=YES'";
            en.Query = "select * from [Sheet1$]";

            SeriesList sList = en.GetSeriesListOfGantt(AxisDataType.DateTime, "항목", "시작일자", "종료일자");

            sList.ChartType = ChartType.Gantt;
            sList.AxisFactor.YAxis.DataType = AxisDataType.DateTime;
            sList.AxisFactor.YAxis.SetAxisStep(new DateTime(2012, 3, 1), new DateTime(2012, 9, 20), 30);
            //sList.AxisFactor.YAxis.DateTimeFormat = "MM-dd";

            sList.AxisFactor.XAxis.Interval = 1;
            sList.AxisFactor.XAxis.LabelFormat = new StringFormat();
            sList.AxisFactor.XAxis.LabelFormat.LineAlignment = StringAlignment.Center;
            sList.AxisFactor.XAxis.LabelFormat.Alignment = StringAlignment.Near;
            sList.AxisFactor.XAxis.IsShowTick = false;

            AxisMarker mk = new AxisMarker("Start Project", DateTime.Parse("2012-04-01"));
            mk.BringToFront = true;
            mk.TextFormat.FormatFlags = StringFormatFlags.DirectionVertical;
            mk.TextFormat.LineAlignment = StringAlignment.Near;
            mk.TextFormat.Alignment = StringAlignment.Far;
            mk.Line.DashStyle = System.Drawing.Drawing2D.DashStyle.Dash;
            mk.Line.LineColor = Color.Red;
            mk.Line.LineWidth = 1;
            mk.Label.ForeColor = Color.Red;
            sList.AxisFactor.YAxis.Markers.Add(mk);

            AxisMarker mk2 = new AxisMarker("Today", DateTime.Parse("2012-07-11"));
            mk2.BringToFront = true;
            mk2.TextFormat.FormatFlags = StringFormatFlags.DirectionVertical;
            mk2.TextFormat.LineAlignment = StringAlignment.Near;
            mk2.TextFormat.Alignment = StringAlignment.Far;
            mk2.Line.DashStyle = System.Drawing.Drawing2D.DashStyle.Solid;
            mk2.Line.LineColor = Color.Blue;
            mk2.Line.LineWidth = 1;
            mk2.Label.ForeColor = Color.Blue;
            sList.AxisFactor.YAxis.Markers.Add(mk2);

            sList.SeriesCollection[0].items[0].IsMilestone = true;
            sList.SeriesCollection[0].items[9].IsMilestone = true;
            sList.SeriesCollection[0].items[15].IsMilestone = true;

            sList.SeriesCollection[0].items[2].IsGroupBoss = true;
            sList.SeriesCollection[0].items[5].IsGroupBoss = true;
            sList.SeriesCollection[0].items[11].IsGroupBoss = true;

            sList.SeriesCollection[0].items[1].ItemColor = Color.Red;

            sList.SeriesCollection[0].items[2].ItemColor = Color.FromArgb(107, 202, 102);
            sList.SeriesCollection[0].items[3].ItemColor = Color.FromArgb(107, 202, 102);
            sList.SeriesCollection[0].items[4].ItemColor = Color.FromArgb(107, 202, 102);

            sList.SeriesCollection[0].items[5].ItemColor = Color.FromArgb(74, 126, 225);
            sList.SeriesCollection[0].items[6].ItemColor = Color.FromArgb(74, 126, 225);
            sList.SeriesCollection[0].items[7].ItemColor = Color.FromArgb(74, 126, 225);
            sList.SeriesCollection[0].items[8].ItemColor = Color.FromArgb(74, 126, 225);
            sList.SeriesCollection[0].items[10].ItemColor = Color.FromArgb(74, 126, 225);

            sList.SeriesCollection[0].items[11].ItemColor = Color.FromArgb(140, 202, 249);
            sList.SeriesCollection[0].items[12].ItemColor = Color.FromArgb(140, 202, 249);
            sList.SeriesCollection[0].items[13].ItemColor = Color.FromArgb(140, 202, 249);

            sList.SeriesCollection[0].items[14].ItemColor = Color.Yellow;
            sList.SeriesCollection[0].items[15].ItemColor = Color.Red;

            sList.SeriesCollection[0].items[2].ParentIndex = 8;
            sList.SeriesCollection[0].items[4].ParentIndex = 5;
            sList.SeriesCollection[0].items[5].ParentIndex = 13;

            sList.SeriesCollection[0].items[6].ParentIndex = 9;
            sList.SeriesCollection[0].items[7].ParentIndex = 9;
            sList.SeriesCollection[0].items[8].ParentIndex = 9;
            sList.SeriesCollection[0].items[9].ParentIndex = 10;

            sList.SeriesCollection[0].items[14].ParentIndex = 15; 

            sList.SeriesCollection[0].items[4].GanttProcess.Percent = 1;

            sList.SeriesCollection[0].items[5].GanttProcess.Percent = (1 + 0.79 + 0.8 + 0.23) / 4;
            sList.SeriesCollection[0].items[6].GanttProcess.Percent = 1;
            sList.SeriesCollection[0].items[7].GanttProcess.Percent = 0.79;
            sList.SeriesCollection[0].items[8].GanttProcess.Percent = 0.8;
            sList.SeriesCollection[0].items[10].GanttProcess.Percent = 0.23; 

            sList.SeriesCollection[0].ArrowLine.LineWidth = 1;
            sList.SeriesCollection[0].ArrowLine.DashStyle = System.Drawing.Drawing2D.DashStyle.Solid;
            sList.SeriesCollection[0].ArrowLine.LineColor = Color.Red;

            sList.AxisFactor.Orientation = AxisOrientation.TopLeft; 

            this.hHippoChart3.Titles.Label.Text = "HIPPOCHART PROJECT SCHEDULES";
            this.hHippoChart3.SeriesListDictionary.Add(sList);
            this.hHippoChart3.LegendBox.Visible = false;
            this.hHippoChart3.DrawChart();

        }

        /// <summary>
        /// 각종 이벤트 샘플 코드 (마우브 이벤트)
        /// </summary>
        private void DrawEventSample1()
        {
            this.hHippoChart4.SeriesListDictionary.Clear();

            SeriesList sList = new SeriesList();
            sList.ChartType = ChartType.Column;

            Random r = new Random();
            for (int i = 0; i < 1; i++)
            {
                Series sr = new Series();
                sr.Line.LineWidth = 4;
                sr.Points.Width = 10;
                sr.Points.PointType = PointType.FillCircle;
                sr.IsLineShadowEffect = true;

                for (int x = 0; x < 5; x++)
                {
                    SeriesItem item = new SeriesItem();
                    item.Name = "item" + x.ToString();
                    item.YValue = r.Next(9000);

                    item.Balloon = new Balloon();
                    item.Balloon.Label.Text = item.YValue.ToString();
                    item.Balloon.Visible = false;

                    sr.items.Add(item);
                }
                sList.SeriesCollection.Add(sr);
            }

            this.hHippoChart4.SeriesListDictionary.Add(sList);
            this.hHippoChart4.DrawChart();
        }

        /// <summary>
        /// 마우스 갖다대면 수치 보이게 하는 코드
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void hHippoChart4_ChartMouseMove(object sender, MouseEventArgs e)
        {
            for (int i = 0; i < this.hHippoChart4.SeriesListDictionary[0].SeriesCollection[0].items.Count; i++)
            {
                PointF firstpoint = this.hHippoChart4.SeriesListDictionary[0].SeriesCollection[0].items[i].FigurePoint;

                float lastPoX = (float)(firstpoint.X + this.hHippoChart4.SeriesListDictionary[0].SeriesCollection[0].items[i].Column.Width);
                float lastPoY = (float)(firstpoint.Y + this.hHippoChart4.SeriesListDictionary[0].AxisFactor.YAxis.UnitPixel * this.hHippoChart4.SeriesListDictionary[0].SeriesCollection[0].items[i].YValue);

                PointF lastPoint = new PointF(lastPoX, lastPoY);

                if (e.X >= firstpoint.X && e.X <= lastPoint.X && e.Y >= firstpoint.Y && e.Y <= lastPoint.Y)
                {
                    this.hHippoChart4.SeriesListDictionary[0].SeriesCollection[0].items[i].Balloon.Visible = true;
                    this.hHippoChart4.SeriesListDictionary[0].SeriesCollection[0].items[i].ItemColor = Color.YellowGreen;
                }
                else
                {
                    this.hHippoChart4.SeriesListDictionary[0].SeriesCollection[0].items[i].Balloon.Visible = false;
                    this.hHippoChart4.SeriesListDictionary[0].SeriesCollection[0].items[i].ItemColor = Color.Empty;
                }
            }

            this.hHippoChart4.DrawChart();
        }

        /// <summary>
        /// 줌 기능을 위한 샘플
        /// </summary>
        private void DrawEventSample2()
        {
            this.hHippoChart5.SeriesListDictionary.Clear();

            SeriesList sList = new SeriesList();
            sList.ChartType = ChartType.Line;
            sList.AxisFactor.XAxis.DataType = AxisDataType.Number;
             
            for (int i = 0; i < 1; i++)
            {
                Series sr = new Series();
                sr.Column.DesignType = AreaDesignType.Gradation;
                sr.Line.LineWidth = 5;

                for (int x = 0; x < 20; x++)
                {
                    SeriesItem item = new SeriesItem();
                    item.Name = x.ToString();
                    item.XValue = x;
                    item.YValue = x * 5 * (x % 2 + 1) - 20;

                    sr.items.Add(item);
                }
                sList.SeriesCollection.Add(sr);
            }

            this.hHippoChart5.SeriesListDictionary.Add(sList);
            this.hHippoChart5.DrawChart();
        }

        // 줌 기능을 위한 변수 
        Rectangle rec;

        /// <summary>
        /// 줌 기능을 위한 이벤트 핸들러 코드들
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param> 
        private void hHippoChart5_ChartMouseUp(object sender, MouseEventArgs e)
        {
            if (e.Button == MouseButtons.Left)
            {
                SeriesItemCollection items = this.hHippoChart5.SeriesListDictionary[0].SeriesCollection[0].items;

                double zeroX = this.hHippoChart5.SeriesListDictionary[0].AxisFactor.Zero.X;
                double zeroY = this.hHippoChart5.SeriesListDictionary[0].AxisFactor.Zero.Y - this.hHippoChart5.Height;

                double maxvalue_X = double.MinValue;
                double minvalue_X = double.MaxValue;
                double maxvalue_Y = double.MinValue;
                double minvalue_Y = double.MaxValue;

                bool ret = false;

                double recnewX = zeroX + (rec.Left - this.Location.X - this.hHippoChart5.Location.X);
                double recnewY = zeroY + (rec.Top + this.Location.Y + this.hHippoChart5.Location.Y);

                foreach (SeriesItem item in items)
                {
                    double XPoint = item.FigurePoint.X;
                    double Ypoint = item.FigurePoint.Y;

                    if (XPoint >= recnewX && XPoint <= recnewX + rec.Width
                        )
                    {
                        if (item.XValue >= maxvalue_X)
                        {
                            maxvalue_X = item.XValue;
                        }

                        if (item.XValue <= minvalue_X)
                        {
                            minvalue_X = item.XValue;
                        }

                        ret = true;
                    }

                    if (Ypoint >= recnewY && Ypoint <= recnewY + rec.Height
                        )
                    {
                        if (item.YValue >= maxvalue_Y)
                        {
                            maxvalue_Y = item.YValue;
                        }

                        if (item.YValue <= minvalue_Y)
                        {
                            minvalue_Y = item.YValue;
                        }

                        ret = true;
                    }
                }

                if (ret)
                {
                    this.hHippoChart5.SeriesListDictionary[0].AxisFactor.XAxis.SetAxisStep(minvalue_X, maxvalue_X, 1);
                    this.hHippoChart5.SeriesListDictionary[0].AxisFactor.YAxis.SetAxisStep(minvalue_Y, maxvalue_Y, 10);
                    this.hHippoChart5.DrawChart();
                }
            }
        }

        private void hHippoChart5_ChartMouseMove(object sender, MouseEventArgs e)
        {
            rec = this.hHippoChart5.DragRectangle; 
        }

        /// <summary>
        /// 줌 해제하기
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void button3_Click(object sender, EventArgs e)
        {
            this.hHippoChart5.SeriesListDictionary[0].AxisFactor.XAxis.IsAutoSetting = true;
            this.hHippoChart5.SeriesListDictionary[0].AxisFactor.YAxis.IsAutoSetting = true;
            this.hHippoChart5.DrawChart();
        }

        private void hHippoChart6_ChartSizeChanged(object sender, EventArgs e)
        {

        }

        /// <summary>
        /// 계기판 차트
        /// </summary>
        private void DrawGaugeChart()
        {
            this.hHippoChart6.SeriesListDictionary.Clear();


            SeriesList sList = new SeriesList();
            sList.ChartType = ChartType.Gauge2; 

            Random r = new Random();
            for (int i = 0; i < 7; i++)
            {
                Series sr = new Series();

                sr.UnAxisFactor.Axis.SetAxisStep(0, 100, 20);

                if (i == 0) sr.Gauge.ShapeType2 = ShapeType2.Gauge6;
                if (i == 1) sr.Gauge.ShapeType2 = ShapeType2.Gauge7;
                if (i == 2) sr.Gauge.ShapeType2 = ShapeType2.Gauge1;
                if (i == 3) sr.Gauge.ShapeType2 = ShapeType2.Gauge2;
                if (i == 4) sr.Gauge.ShapeType2 = ShapeType2.Gauge3;
                if (i == 5) sr.Gauge.ShapeType2 = ShapeType2.Gauge4;
                if (i == 6) sr.Gauge.ShapeType2 = ShapeType2.Gauge5;

                for (int x = 0; x < 1; x++)
                {
                    SeriesItem item = new SeriesItem();
                    item.Name = x.ToString();
                    item.YValue = r.Next(22, 99);

                    sr.items.Add(item);
                }

                sList.SeriesCollection.Add(sr);
            }

            this.hHippoChart6.LegendBox.Visible = false;
            this.hHippoChart6.SeriesListDictionary.Add(sList);
            this.hHippoChart6.DrawChart();
        }

        private void button4_Click(object sender, EventArgs e)
        {
            this.hHippoChart6.SeriesListDictionary.Clear();

            SeriesList sList = new SeriesList();
            sList.ChartType = ChartType.Gauge2;

            Random r = new Random();
            for (int i = 0; i < 7; i++)
            {
                Series sr = new Series();

                sr.UnAxisFactor.Axis.SetAxisStep(0, 100, 20);

                if (i == 0) sr.Gauge.ShapeType2 = ShapeType2.Gauge6;
                if (i == 1) sr.Gauge.ShapeType2 = ShapeType2.Gauge7;
                if (i == 2) sr.Gauge.ShapeType2 = ShapeType2.Gauge1;
                if (i == 3) sr.Gauge.ShapeType2 = ShapeType2.Gauge2;
                if (i == 4) sr.Gauge.ShapeType2 = ShapeType2.Gauge3;
                if (i == 5) sr.Gauge.ShapeType2 = ShapeType2.Gauge4;
                if (i == 6) sr.Gauge.ShapeType2 = ShapeType2.Gauge5;

                for (int x = 0; x < 1; x++)
                {
                    SeriesItem item = new SeriesItem();
                    item.Name = x.ToString();
                    item.YValue = r.Next(22, 99);

                    sr.items.Add(item);
                }

                sList.SeriesCollection.Add(sr);
            }

            this.hHippoChart6.LegendBox.Visible = false;
            this.hHippoChart6.SeriesListDictionary.Add(sList);
            this.hHippoChart6.DrawChart();
        }
    }
}
